@@ -5,14 +5,13 @@ set -e
 test -n "$1"
 PLUGIN="$1"
 
-BASEURL=https://hg.gajim.org
 REPO=gajim-plugins
 PACKAGE=gajim-$(echo "$PLUGIN" | sed 's/_//g')
 
 CWD=$(pwd)
 TMPDIR=$(mktemp -d)
 cd "$TMPDIR"
-hg clone "$BASEURL"/"$REPO"/
+git clone https://dev.gajim.org/gajim/"$REPO".git
 VERSION=$(grep ^version: ./"$REPO"/"$PLUGIN"/manifest.ini | sed 's/.*: *//')
 FILENAME="$CWD"/../"$PACKAGE"_"$VERSION".orig.tar.gz
 test ! -e "$FILENAME"
